#!/bin/csh -x
############################################################################
#
#  Program Name: transfer.csh
#
#  This script transfers the following GSIP (Verstion 3) result files to DDS. 
#
#    1) GENHEM: GOES-EAST (goes-13) North Hemisphere hourly level-2 files
#    2) GEDISK: GOES-EAST (goes-13) Full Disk 3-hourly level-2 files
#    3) GWNHEM: GOES-WEST (goes-15) North Hemisphere hourly level-2 files
#    4) GWDISK: GOES-WEST (goes-15) Full Disk 3-hourly level-2 files
#    5) MSGFD : METEOSAT  Full Disk hourly level-2 files
#    6) MTSFD : MTSAT     Full Disk hourly level-2 files
#    7) DAGLOB: Level3 Global Daily Average file
#     
# CCR02226 : Implement GSIP-V3 on gsrdev and gsrprod (Venkata Rao Anne, SGT, 03/2014)
#
#
############################################################################
#set dirpath = `dirname $0`
#echo "dirpath = "$dirpath
#source $dirpath/set_gsip_v3_subdirs.scr

if ($#argv == 4) then
   set CURDATE = $1  # CURDATE
   set PREVHR = $2   # PREVHR
   set SATID = $3    # SATID
   set DOMAIN = $4   # DOMAIN (GENHEM/GEDISK/GWNHEM/GWDISK/MSGFD/MTSFD)
else if ($#argv == 3) then
   set YYYY = $1  # CURRENT YEAR
   set JDATE = $2   # CURRENT JULIAN DAY
   set DOMAIN = $3   # GLOBAL_DOMAIN (DAGLOB)
else
   echo " Incorrect number of orguments to trasfer.csh script "
   exit 1
endif 

set DDS_SERVER=`grep "^DDS_SERVER=" $CONTROL_DIR/gsip_fd.ini | cut -f2 -d"="`
echo " DDS_SERVER " "$DDS_SERVER"

# prepare  GSIP-V3 file before sending to  DDS

switch ($DOMAIN)

 case GWNHEM:
     set SETMIN = 00
     set FILENAME1 = "gsipL2_goes"$SATID"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     set FILENAME2 = "gsipL2_goes"$SATID"_"$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     breaksw

 case GWDISK:
     set SETMIN = 00
     set FILENAME1 = "gsipL2_goes"$SATID"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     set FILENAME2 = "gsipL2_goes"$SATID"_"$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     breaksw

 case GENHEM:
    set SETMIN = 45
    set FILENAME1 = "gsipL2_goes"$SATID"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
    set FILENAME2 = "gsipL2_goes"$SATID"_"$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
    breaksw

 case GEDISK:
     set SETMIN = 45
     set FILENAME1 = "gsipL2_goes"$SATID"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     set FILENAME2 = "gsipL2_goes"$SATID"_"$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     breaksw

 case MSGFD:
     set SETMIN = 30
  if ($SATID == 52) then
       set SATNAME="met09_"
     else if ($SATID == 53) then
       set SATNAME="met10_"
     else if ($SATID == 51) then
       set SATNAME="met08_"
     endif
     set FILENAME1 = "gsipL2_"$SATNAME$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     set FILENAME2 = "gsipL2_"$SATNAME$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     breaksw

 case MTSFD:
     if ( $SATID == 84 ) then
         set SATNAME="mtsat01_"
         set SETMIN = 30
     else if ($SATID == 85) then
         set SATNAME="mtsat02_"
         set SETMIN = 32
     endif
     set FILENAME1 = "gsipL2_"$SATNAME$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     set FILENAME2 = "gsipL2_"$SATNAME$DOMAIN"_"$CURDATE"_"$PREVHR$SETMIN".nc.gz"
     breaksw

 case DAGLOB:
     set FILENAME1 = "gsipL3_gda_"$YYYY$JDATE".nc.gz"
     set FILENAME2 = "gsipL3_global_GDA_"$YYYY$JDATE".nc.gz"
     breaksw

 default:
     echo " transfer.csh: wrong Domain name ($DOMAIN) Goodbye"
     exit 1
endsw

#Sending GSIP-fd file to DDS

echo "cd push" >$WORK_DIR/dds_$DOMAIN.list
echo "Transfer to DDS FILENAME = "$FILENAME2
echo "put $RESULTS_DIR$DOMAIN/$FILENAME1 xfr_$FILENAME2" >>$WORK_DIR/dds_$DOMAIN.list
echo "rename xfr_$FILENAME2 $FILENAME2" >>$WORK_DIR/dds_$DOMAIN.list
ftp $DDS_SERVER <$WORK_DIR/dds_$DOMAIN.list
#rm $WORK_DIR/dds_$DOMAIN.list
exit
